==> gstep-core-0.5.0.tar.gz: gstep-core-0.5.0/xdps/Headers/gnustep/xdps/PXKDPSContext.h <==
/* 
   PXKDPSContext.h

   NSDPSContext for GNUstep GUI X/DPS Backend

   Copyright (C) 1996 Free Software Foundation, Inc.

   Author:  Scott Christley <scottc@net-community.com>
   Date: April 1996
   
   This file is part of the GNUstep GUI X/DPS Backend.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; see the file COPYING.LIB.
   If not, write to the Free Software Foundation,
   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/ 

#ifndef _GNUstep_H_PXKDPSContext
#define _GNUstep_H_PXKDPSContext

#include <gnustep/xdps/stdpxk.h>
#include <DPSClient/NSDPSContext.h>

@class PXKWindow;

@interface PXKDPSContext : NSDPSContext
{
}

@end

//
// Methods for X Window System implementation
//
@interface PXKDPSContext (GNUstepXDPS)

- (Display *)xDisplay;
- (void)setXDisplay:(Display *)xdisplay;
- (DPSContext)xDPSContext;
- (void)createDPSContext;
- (void)setXDrawable:(PXKWindow*)w;
- (PXKWindow*)drawableWindow;

- (NSPoint)userPointFromXPoint:(NSPoint)xPoint;
- (NSPoint)XPointFromUserPoint:(NSPoint)userPoint;
- (NSSize)userSizeFromXSize:(NSSize)xSize;
- (NSSize)XSizeFromUserSize:(NSSize)userSize;
- (id)getCTM;

@end

#endif /* _GNUstep_H_PXKDPSContext */

==> gstep-core_0.5.0.981229.orig.tar.gz: gstep-core-0.5.0.981229.orig/xdps/Headers/gnustep/xdps/PXKDPSContext.h <==
/* 
   PXKDPSContext.h

   NSDPSContext for GNUstep GUI X/DPS Backend

   Copyright (C) 1996 Free Software Foundation, Inc.

   Author:  Scott Christley <scottc@net-community.com>
   Date: April 1996
   
   This file is part of the GNUstep GUI X/DPS Backend.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; see the file COPYING.LIB.
   If not, write to the Free Software Foundation,
   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/ 

#ifndef _GNUstep_H_PXKDPSContext
#define _GNUstep_H_PXKDPSContext

#include <gnustep/xdps/stdpxk.h>
#include <gnustep/xdps/NSDPSContext.h>

@class PXKWindow;

@interface PXKDPSContext : NSDPSContext
{
}

@end

//
// Methods for X Window System implementation
//
@interface PXKDPSContext (GNUstepXDPS)

- (Display *)xDisplay;
- (void)setXDisplay:(Display *)xdisplay;
- (DPSContext)xDPSContext;
- (void)createDPSContext;
- (void)setXDrawable:(PXKWindow*)w;
- (PXKWindow*)drawableWindow;

- (NSPoint)userPointFromXPoint:(NSPoint)xPoint;
- (NSPoint)XPointFromUserPoint:(NSPoint)userPoint;
- (NSSize)userSizeFromXSize:(NSSize)xSize;
- (NSSize)XSizeFromUserSize:(NSSize)userSize;
- (id)getCTM;

@end

#endif /* _GNUstep_H_PXKDPSContext */
